%% CVL Monogenic signal toolbox
%
% File revision $Id: Contents.m 7501 2007-05-15 09:31:41Z mfe $
%
% This toolbox contains the monogenic signal class and some misc. 
% functions. Most of the functions are based on stuff that Michael 
% has been doing in his PhD and at the CVL lab.
%
% The basic functionalities have been collected in a monogenic class,
% such that most functions can be accessed in the usual way, e.g., array
% indexing, field selection, orientation, amplitude, phase, etc.
% In the constructor different methods and parameters for generating
% monogenic objects can be selected.
%
% Note that the classes are written using the new, unofficial Matlab OO 
% system (MCOS), and requires Matlab 7.3. The classes will be maintained to 
% work with the latest matlab version until MCOS is officially released.
%

%    Copyright (c) 2007 Michael Felsberg, mfe@isy.liu.se
%
%    This program is free software; you can redistribute it and/or modify
%    it under the terms of the GNU General Public License as published by
%    the Free Software Foundation; either version 2 of the License, or
%    (at your option) any later version.
%
%    This program is distributed in the hope that it will be useful,
%    but WITHOUT ANY WARRANTY; without even the implied warranty of
%    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
%    GNU General Public License for more details.
%
%    You should have received a copy of the GNU General Public License
%    along with this program; if not, write to the Free Software
%    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

%% monogenic
help monogenic

%% monogenic/amplit
help monogenic/amplit

%% monogenic/conj
help monogenic/conj

%% monogenic/disp
help monogenic/disp

%% monogenic/end
help monogenic/end

%% monogenic/log
help monogenic/log

%% monogenic/orient
help monogenic/orient

%% monogenic/phase
help monogenic/phase

%% monogenic/recon
help monogenic/recon

%% monogenic/size
help monogenic/size

%% monogenic/subsasgn
help monogenic/subsasgn

%% monogenic/subsref
help monogenic/subsref

%% example to use
cvlUseToolbox('testimages');

%% load image and compute
bild=imread('house.png');

params.scales=[1 2 3];
params.coeffs=[1 -2 1];
Md=monogenic(bild,'dct',params);
Ms=monogenic(bild,'sqf');
params.scales=1.3;
Mg=monogenic(bild,'get',params);

%% DCT image

imshow(Md.image,[]);

%% DCT flux

compimshow(Md.flux);

%% SQF image

imshow(Ms.image,[]);

%% SQG flux

compimshow(Ms.flux);

%% GET image

imshow(Mg.image,[]);

%% GET flux

compimshow(Mg.flux);

%% compute monogenic signal
m=monogenic(bild,'dct');

%% compute conjugate log
l=log(m);

%% reconstruct from amplitude
imshow(recon(monogenic(l.even,'dct')),[0 255]-mean(bild(:)));

%% reconstruct from phase
imshow(recon(conj(monogenic(conj(l.odd),'dct'))),[]);

%% phase II
phi=phase(m);
ori=orient(monogenic(phi));
imshow(recon(conj(monogenic(exp(-i*ori).*phi,'dct'))),[]);

%% DPC edge detection
M=monogenic(bild,'dct');
Ms=monogenic(bild,'dcts');
PC=M.image.*Ms.flux-Ms.image.*M.flux;
[z,s,o]=zero_lin_2(real(PC),imag(PC),3);
t=100;
disp(['Slope threshold: ' num2str(t)]);
imshow(z.*(s>t));

%% local frequency estimation

M=monogenic(bild,'sqf');
Ms=monogenic(bild,'sqfs');
omega=(M.image.*Ms.image+real(M.flux).*real(Ms.flux)+imag(M.flux).*...
	imag(Ms.flux))./amplit(M).^2;
imshow(omega,[]),colorbar;
